//------------------------------------------------------------------------------
// Copyright (c) 2004, Perforce Software, Inc.  All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// 
// 1.  Redistributions of source code must retain the above copyright
//     notice, this list of conditions and the following disclaimer.
// 
// 2.  Redistributions in binary form must reproduce the above copyright
//     notice, this list of conditions and the following disclaimer in the
//     documentation and/or other materials provided with the distribution.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE SOFTWARE, INC. BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//------------------------------------------------------------------------------
#include <clientapi.h>
#include <strtable.h>
#include "submituser.h"

//
// The message that's sent from the server to announce successful
// commit of a change
static StrRef	commitMsg1( "%change% submitted." );
static StrRef	commitMsg2( "%change% renamed %newChange% and submitted." );

//
// Only called when we run the submit. Here we simply watch for the 
// changelist being committed, and use the new changelist number to
// generate a suitable 'p4 fstat //...@change,change' command to be
// used later to identify these files.
//
void
SubmitUser::Message( Error *err )
{
    // Ensure default behaviour happens
    ClientUser::Message( err );

    if( !err->IsInfo() ) return;
    
    StrPtr *	change		= varList->GetVar( "change" );
    StrPtr *	nchange		= varList->GetVar( "newChange" );

    if( change && ( commitMsg1 == err->GetId( 0 )->fmt ) )
    {
	committed = 1;
	StrBuf	t;
	StrRef 	c;
	c = *change;
	c += StrRef( "Change " ).Length();
	t << "//...@" << c << ",@" << c;
	PushFile( &t );
    }
    else if( nchange && ( commitMsg2 == err->GetId( 0 )->fmt ) )
    {
	committed = 1;
	StrBuf	t;
	StrRef	c;
	c = *nchange;
	c += StrRef( "change " ).Length();
	t << "//...@" << c << ",@" << c;
	PushFile( &t );
    }
}
